@@ -9,7 +9,7 @@ function(x,y)
 		print("Length Error")
 	else
 		c<-.Fortran("rs_cov",c=as.double(0),
-		            as.double(x),as.double(y),mean.f(x),mean.f(y),
+		            as.double(x),as.double(y),as.double(mean_f(x)),as.double(mean_f(y)),
 		            as.integer(n),PACKAGE="stima")$c
 	return(c)
 }
