@@ -16,7 +16,7 @@
       integer nodvec(m)
       real(8)  dat(m,n),res(2),col(m)
 !
-      include 'rs_calls.h'
+!      include 'rs_calls.h'
 !
 !     Local variables
 !
