@@ -10,7 +10,7 @@
       integer n
       real(8)  x(n),m
 !
-      include 'rs_calls.h'
+!      include 'rs_calls.h'
 !
 ! Local variables
 !
